NeuralProphet
Description: Neuralprophet - A simple timesereis forecasting framework.

Paper Docs

# Explainable Forecasting at Scale

NeuralProphet bridges the gap between traditional time-series models and deep learning methods. It's based on PyTorch and can be installed using pip.

GitHub

    from neuralprophet import NeuralProphet
    import pandas as pd

    df = pd.read_csv('toiletpaper_daily_sales.csv')

    m = NeuralProphet()

    metrics = m.fit(df, freq="D")

    forecast = m.predict(df)

Star